<!doctype html>
<html>

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://cdn.tailwindcss.com"></script>
</head>

<body>
    <header class="bg-white-800 text-white p-4">
        <div class="container mx-auto flex justify-between items-center">
            <img src="/static/logo.png" alt="AutoTrain" , class="w-32">
        </div>
    </header>

    <div class="form-container max-w-lg mx-auto mt-10 p-6 shadow-2xl">
        <h1 class="text-2xl font-bold mb-10">Login</h1>
        <p class="text-gray-500 text-sm mb-10">Please <a href="/login/huggingface" target="_blank">login</a> to use
            AutoTrain</p>
        <div style="text-align: center;">
            <a href="/login/huggingface" target="_blank">
                <img src="https://huggingface.co/datasets/huggingface/badges/resolve/main/sign-in-with-huggingface-xl.svg"
                    alt="Login using Hugging Face">
            </a>
        </div>
    </div>
</body>

</html>